@@ -12,9 +12,6 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-from __future__ import division
-from __future__ import print_function
-
 import multiprocessing as mp
 import random
 import sys
@@ -24,7 +21,7 @@ from gevent import monkey as curious_george
 curious_george.patch_all(thread=False, select=False)
 import gevent
 import marktime
-from six.moves import urllib
+import urllib
 from zaqarclient.transport import errors
 
 from zaqar.bench import config
