@@ -11,15 +11,12 @@
 # WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 # License for the specific language governing permissions and limitations under
 # the License.
-
-from __future__ import print_function
 import functools
 import sys
 
 from oslo_config import cfg
 from oslo_log import log as logging
 
-from zaqar.i18n import _
 
 CONF = cfg.CONF
 
@@ -35,7 +32,7 @@ def _fail(returncode, ex):
 
     print(ex, file=sys.stderr)
 
-    LOG.exception(ex)
+    LOG.exception('Exception encountered:')
     sys.exit(returncode)
 
 
@@ -53,7 +50,7 @@ def runnable(func):
             logging.setup(CONF, 'zaqar')
             func()
         except KeyboardInterrupt:
-            LOG.info(_(u'Terminating'))
+            LOG.info('Terminating')
         except Exception as ex:
             _fail(1, ex)
 
