@@ -41,51 +41,37 @@ default_subscription_ttl = cfg.IntOpt(
 
 max_queues_per_page = cfg.IntOpt(
     'max_queues_per_page', default=20,
-    deprecated_name='queue_paging_uplimit',
-    deprecated_group='limits:transport',
     help='Defines the maximum number of queues per page.')
 
 
 max_messages_per_page = cfg.IntOpt(
     'max_messages_per_page', default=20,
-    deprecated_name='message_paging_uplimit',
-    deprecated_group='limits:transport',
     help='Defines the maximum number of messages per page.')
 
 
 max_subscriptions_per_page = cfg.IntOpt(
     'max_subscriptions_per_page', default=20,
-    deprecated_name='subscription_paging_uplimit',
-    deprecated_group='limits:transport',
     help='Defines the maximum number of subscriptions per page.')
 
 
 max_messages_per_claim_or_pop = cfg.IntOpt(
     'max_messages_per_claim_or_pop', default=20,
-    deprecated_name='max_messages_per_claim',
     help='The maximum number of messages that can be claimed (OR) '
          'popped in a single request')
 
 
 max_queue_metadata = cfg.IntOpt(
     'max_queue_metadata', default=64 * 1024,
-    deprecated_name='metadata_size_uplimit',
-    deprecated_group='limits:transport',
     help='Defines the maximum amount of metadata in a queue.')
 
 
 max_messages_post_size = cfg.IntOpt(
     'max_messages_post_size', default=256 * 1024,
-    deprecated_name='message_size_uplimit',
-    deprecated_group='limits:transport',
-    deprecated_opts=[cfg.DeprecatedOpt('max_message_size')],
     help='Defines the maximum size of message posts.')
 
 
 max_message_ttl = cfg.IntOpt(
     'max_message_ttl', default=1209600,
-    deprecated_name='message_ttl_max',
-    deprecated_group='limits:transport',
     help='Maximum amount of time a message will be available.')
 
 
@@ -96,15 +82,11 @@ max_message_delay = cfg.IntOpt(
 
 max_claim_ttl = cfg.IntOpt(
     'max_claim_ttl', default=43200,
-    deprecated_name='claim_ttl_max',
-    deprecated_group='limits:transport',
     help='Maximum length of a message in claimed state.')
 
 
 max_claim_grace = cfg.IntOpt(
     'max_claim_grace', default=43200,
-    deprecated_name='claim_grace_max',
-    deprecated_group='limits:transport',
     help='Defines the maximum message grace period in seconds.')
 
 
@@ -125,22 +107,21 @@ max_pools_per_page = cfg.IntOpt(
 
 
 client_id_uuid_safe = cfg.StrOpt(
-    'client_id_uuid_safe', default='strict', choices=['strict', 'off'],
-    help='Defines the format of client id, the value could be '
-         '"strict" or "off". "strict" means the format of client id'
-         ' must be uuid, "off" means the restriction be removed.')
-
+    'client_id_uuid_safe', default='strict',
+    choices=[('strict', 'accept only valid uuid'),
+             ('off', 'accept any string')],
+    help='Defines the format of client id.')
 
 min_length_client_id = cfg.IntOpt(
-    'min_length_client_id', default='10',
-    help='Defines the minimum length of client id if remove the '
-         'uuid restriction. Default is 10.')
+    'min_length_client_id', default=10,
+    help='Defines the minimum length of client id This is used only when '
+         'client_id_uuid_safe is off.')
 
 
 max_length_client_id = cfg.IntOpt(
-    'max_length_client_id', default='36',
-    help='Defines the maximum length of client id if remove the '
-         'uuid restriction. Default is 36.')
+    'max_length_client_id', default=36,
+    help='Defines the maximum length of client id. This is used only when '
+         'client_id_uuid_safe is off.')
 
 
 message_delete_with_claim_id = cfg.BoolOpt(
