@@ -18,9 +18,14 @@ import os
 import fixtures
 from oslo_config import cfg
 from oslo_log import log
+from osprofiler import opts
 import testtools
 
-from zaqar.common import configs
+from zaqar.conf import default
+from zaqar.conf import drivers
+from zaqar.conf import notification
+from zaqar.conf import profiler
+from zaqar.conf import signed_url
 from zaqar.tests import helpers
 
 
@@ -52,17 +57,20 @@ class TestBase(testtools.TestCase):
             self.conf = self.load_conf(self.config_file)
         else:
             self.conf = cfg.ConfigOpts()
+            self.conf(args=[], project='zaqar')
 
-        self.conf.register_opts(configs._GENERAL_OPTIONS)
-        self.conf.register_opts(configs._DRIVER_OPTIONS,
-                                group=configs._DRIVER_GROUP)
-        self.conf.register_opts(configs._NOTIFICATION_OPTIONS,
-                                group=configs._NOTIFICATION_GROUP)
-        self.conf.register_opts(configs._NOTIFICATION_OPTIONS,
-                                group=configs._NOTIFICATION_GROUP)
-        self.conf.register_opts(configs._SIGNED_URL_OPTIONS,
-                                group=configs._SIGNED_URL_GROUP)
-
+        self.conf.register_opts(default.ALL_OPTS)
+        self.conf.register_opts(drivers.ALL_OPTS,
+                                group=drivers.GROUP_NAME)
+        self.conf.register_opts(notification.ALL_OPTS,
+                                group=notification.GROUP_NAME)
+        self.conf.register_opts(signed_url.ALL_OPTS,
+                                group=signed_url.GROUP_NAME)
+        opts.set_defaults(self.conf)
+        self.conf.register_opts(profiler.ALL_OPTS,
+                                group=profiler.GROUP_NAME)
+        self.redis_url = os.environ.get('ZAQAR_TEST_REDIS_URL',
+                                        'redis://127.0.0.1:6379')
         self.mongodb_url = os.environ.get('ZAQAR_TEST_MONGODB_URL',
                                           'mongodb://127.0.0.1:27017')
 
@@ -106,7 +114,7 @@ class TestBase(testtools.TestCase):
         test by the tearDown() method.
         """
         for k, v in kw.items():
-            self.conf.set_override(k, v, group, enforce_type=True)
+            self.conf.set_override(k, v, group)
 
     def _my_dir(self):
         return os.path.abspath(os.path.dirname(__file__))
