@@ -808,7 +808,7 @@ class MessageControllerTest(ControllerBaseTest):
         stored_messages = self.controller.list(self.queue_name,
                                                project=self.project)
 
-        self.assertItemsEqual(['event.data', 'backupId'],
+        self.assertCountEqual(['event.data', 'backupId'],
                               list(next(stored_messages))[0]['body'].keys())
 
     def test_delete_message_from_nonexistent_queue(self):
@@ -1101,9 +1101,9 @@ class ClaimControllerTest(ControllerBaseTest):
         self.assertEqual({"key": "value"}, expected_msg["body"])
 
     def test_delay_queue(self):
-        meta = {'ttl': 1, 'grace': 0}
+        meta = {'ttl': 2, 'grace': 0}
         # Set default message delay for queue.
-        metadata = {'_default_message_delay': 2}
+        metadata = {'_default_message_delay': 3}
         self.queue_controller.set_metadata(self.queue_name,
                                            metadata,
                                            project=self.project)
@@ -1128,12 +1128,12 @@ class ClaimControllerTest(ControllerBaseTest):
                                                     project=self.project)
         self.assertIsNone(claim_id)
         self.assertEqual(0, len(list(messages)))
-        time.sleep(3)
+        time.sleep(4)
         claim_id, messages = self.controller.create(self.queue_name, meta,
                                                     project=self.project)
         self.assertIsNotNone(claim_id)
         self.assertEqual(1, len(list(messages)))
-        time.sleep(1)
+        time.sleep(2)
         self.message_controller.delete(self.queue_name, ids[0],
                                        project=self.project)
 
@@ -1154,12 +1154,12 @@ class ClaimControllerTest(ControllerBaseTest):
                                                     project=self.project)
         self.assertIsNone(claim_id)
         self.assertEqual(0, len(list(messages)))
-        time.sleep(1)
+        time.sleep(2)
         claim_id, messages = self.controller.create(self.queue_name, meta,
                                                     project=self.project)
         self.assertIsNotNone(claim_id)
         self.assertEqual(1, len(list(messages)))
-        time.sleep(1)
+        time.sleep(2)
         self.message_controller.delete(self.queue_name, ids[0],
                                        project=self.project)
 
@@ -1180,7 +1180,7 @@ class ClaimControllerTest(ControllerBaseTest):
                                                     project=self.project)
         self.assertIsNotNone(claim_id)
         self.assertEqual(1, len(list(messages)))
-        time.sleep(1)
+        time.sleep(2)
         self.message_controller.delete(self.queue_name, ids[0],
                                        project=self.project)
 
@@ -1749,14 +1749,14 @@ class CatalogueControllerTest(ControllerBaseTest):
     def test_list(self):
         with helpers.pool_entries(self.controller,
                                   self.pool_ctrl, 10) as expect:
-            values = zip(self.controller.list(u'_'), expect)
+            values = zip(self.controller.list('_'), expect)
             for e, x in values:
                 p, q, s = x
                 self._check_structure(e)
                 self._check_value(e, xqueue=q, xproject=p, xpool=s)
 
     def test_update(self):
-        p2 = u'b'
+        p2 = 'b'
         # NOTE(gengchc2): Remove [group=self.pool_group] in
         # it can be tested for redis as management.
         self.pool_ctrl.create(p2, 100, '127.0.0.1',
@@ -1787,7 +1787,7 @@ class CatalogueControllerTest(ControllerBaseTest):
     def test_get_raises_if_does_not_exist(self):
         with helpers.pool_entry(self.controller,
                                 self.project,
-                                self.queue, u'a') as expect:
+                                self.queue, 'a') as expect:
             p, q, _ = expect
             self.assertRaises(errors.QueueNotMapped,
                               self.controller.get,
@@ -1810,8 +1810,8 @@ class CatalogueControllerTest(ControllerBaseTest):
     def test_insert(self):
         q1 = str(uuid.uuid1())
         q2 = str(uuid.uuid1())
-        self.controller.insert(self.project, q1, u'a')
-        self.controller.insert(self.project, q2, u'a')
+        self.controller.insert(self.project, q1, 'a')
+        self.controller.insert(self.project, q2, 'a')
 
 
 # NOTE(gengchc2): Unittest for new flavor configure scenario.
