@@ -12,12 +12,12 @@
 # License for the specific language governing permissions and limitations under
 # the License.
 
-import json
-import uuid
+from unittest import mock
 
 import ddt
-import mock
+from oslo_serialization import jsonutils
 from oslo_utils import timeutils
+from oslo_utils import uuidutils
 
 from zaqar.common import consts
 from zaqar.tests.unit.transport.websocket import base
@@ -36,7 +36,7 @@ class ClaimsBaseTest(base.V1_1Base):
 
         self.project_id = '7e55e1a7e'
         self.headers = {
-            'Client-ID': str(uuid.uuid4()),
+            'Client-ID': uuidutils.generate_uuid(),
             'X-Project-ID': self.project_id
         }
 
@@ -46,8 +46,8 @@ class ClaimsBaseTest(base.V1_1Base):
 
         with mock.patch.object(self.protocol, 'sendMessage') as msg_mock:
             self.protocol.onMessage(req, False)
-            resp = json.loads(msg_mock.call_args[0][0])
-            self.assertEqual(201, resp['headers']['status'])
+            resp = jsonutils.loads(msg_mock.call_args[0][0])
+            self.assertIn(resp['headers']['status'], [201, 204])
 
         action = consts.MESSAGE_POST
         body = {"queue_name": "skittle",
@@ -70,7 +70,7 @@ class ClaimsBaseTest(base.V1_1Base):
 
         self.protocol.onMessage(req, False)
 
-        resp = json.loads(send_mock.call_args[0][0])
+        resp = jsonutils.loads(send_mock.call_args[0][0])
         self.assertEqual(201, resp['headers']['status'])
 
     def tearDown(self):
@@ -84,7 +84,7 @@ class ClaimsBaseTest(base.V1_1Base):
         req = test_utils.create_request(action, body, self.headers)
         self.protocol.onMessage(req, False)
 
-        resp = json.loads(send_mock.call_args[0][0])
+        resp = jsonutils.loads(send_mock.call_args[0][0])
         self.assertEqual(204, resp['headers']['status'])
 
     @ddt.data('[', '[]', '.', '"fail"')
@@ -97,7 +97,7 @@ class ClaimsBaseTest(base.V1_1Base):
 
         req = test_utils.create_request(action, body, self.headers)
         self.protocol.onMessage(req, False)
-        resp = json.loads(send_mock.call_args[0][0])
+        resp = jsonutils.loads(send_mock.call_args[0][0])
         self.assertEqual(400, resp['headers']['status'])
 
         action = consts.CLAIM_UPDATE
@@ -105,7 +105,7 @@ class ClaimsBaseTest(base.V1_1Base):
 
         req = test_utils.create_request(action, body, self.headers)
         self.protocol.onMessage(req, False)
-        resp = json.loads(send_mock.call_args[0][0])
+        resp = jsonutils.loads(send_mock.call_args[0][0])
         self.assertEqual(400, resp['headers']['status'])
 
     def test_exceeded_claim(self):
@@ -120,7 +120,7 @@ class ClaimsBaseTest(base.V1_1Base):
 
         req = test_utils.create_request(action, body, self.headers)
         self.protocol.onMessage(req, False)
-        resp = json.loads(send_mock.call_args[0][0])
+        resp = jsonutils.loads(send_mock.call_args[0][0])
         self.assertEqual(400, resp['headers']['status'])
 
     @ddt.data((-1, -1), (59, 60), (60, 59), (60, 43201), (43201, 60))
@@ -136,7 +136,7 @@ class ClaimsBaseTest(base.V1_1Base):
 
         req = test_utils.create_request(action, body, self.headers)
         self.protocol.onMessage(req, False)
-        resp = json.loads(send_mock.call_args[0][0])
+        resp = jsonutils.loads(send_mock.call_args[0][0])
         self.assertEqual(400, resp['headers']['status'])
 
     @ddt.data(-1, 59, 43201)
@@ -153,7 +153,7 @@ class ClaimsBaseTest(base.V1_1Base):
 
         req = test_utils.create_request(action, body, self.headers)
         self.protocol.onMessage(req, False)
-        resp = json.loads(send_mock.call_args[0][0])
+        resp = jsonutils.loads(send_mock.call_args[0][0])
         self.assertEqual(400, resp['headers']['status'])
 
     def test_default_ttl_and_grace(self):
@@ -165,7 +165,7 @@ class ClaimsBaseTest(base.V1_1Base):
 
         req = test_utils.create_request(action, body, self.headers)
         self.protocol.onMessage(req, False)
-        resp = json.loads(send_mock.call_args[0][0])
+        resp = jsonutils.loads(send_mock.call_args[0][0])
         self.assertEqual(201, resp['headers']['status'])
 
         action = consts.CLAIM_GET
@@ -174,7 +174,7 @@ class ClaimsBaseTest(base.V1_1Base):
 
         req = test_utils.create_request(action, body, self.headers)
         self.protocol.onMessage(req, False)
-        resp = json.loads(send_mock.call_args[0][0])
+        resp = jsonutils.loads(send_mock.call_args[0][0])
 
         self.assertEqual(200, resp['headers']['status'])
         self.assertEqual(self.defaults.claim_ttl, resp['body']['ttl'])
@@ -191,7 +191,7 @@ class ClaimsBaseTest(base.V1_1Base):
 
         req = test_utils.create_request(action, body, self.headers)
         self.protocol.onMessage(req, False)
-        resp = json.loads(send_mock.call_args[0][0])
+        resp = jsonutils.loads(send_mock.call_args[0][0])
         self.assertEqual(201, resp['headers']['status'])
         claimed_messages = resp['body']['messages']
         claim_id = resp['body']['claim_id']
@@ -203,7 +203,7 @@ class ClaimsBaseTest(base.V1_1Base):
 
         req = test_utils.create_request(action, body, self.headers)
         self.protocol.onMessage(req, False)
-        resp = json.loads(send_mock.call_args[0][0])
+        resp = jsonutils.loads(send_mock.call_args[0][0])
         self.assertEqual(204, resp['headers']['status'])
 
         # Listing messages, by default, won't include claimed, will echo
@@ -213,7 +213,7 @@ class ClaimsBaseTest(base.V1_1Base):
 
         req = test_utils.create_request(action, body, self.headers)
         self.protocol.onMessage(req, False)
-        resp = json.loads(send_mock.call_args[0][0])
+        resp = jsonutils.loads(send_mock.call_args[0][0])
         self.assertEqual(200, resp['headers']['status'])
         self.assertEqual([], resp['body']['messages'])
 
@@ -224,7 +224,7 @@ class ClaimsBaseTest(base.V1_1Base):
 
         req = test_utils.create_request(action, body, self.headers)
         self.protocol.onMessage(req, False)
-        resp = json.loads(send_mock.call_args[0][0])
+        resp = jsonutils.loads(send_mock.call_args[0][0])
         self.assertEqual(200, resp['headers']['status'])
         self.assertEqual([], resp['body']['messages'])
 
@@ -236,7 +236,7 @@ class ClaimsBaseTest(base.V1_1Base):
 
         req = test_utils.create_request(action, body, self.headers)
         self.protocol.onMessage(req, False)
-        resp = json.loads(send_mock.call_args[0][0])
+        resp = jsonutils.loads(send_mock.call_args[0][0])
         self.assertEqual(200, resp['headers']['status'])
         self.assertEqual(resp['body']['messages'], [])
 
@@ -247,13 +247,13 @@ class ClaimsBaseTest(base.V1_1Base):
                 "echo": False}
 
         headers = {
-            'Client-ID': str(uuid.uuid4()),
+            'Client-ID': uuidutils.generate_uuid(),
             'X-Project-ID': self.project_id
         }
 
         req = test_utils.create_request(action, body, headers)
         self.protocol.onMessage(req, False)
-        resp = json.loads(send_mock.call_args[0][0])
+        resp = jsonutils.loads(send_mock.call_args[0][0])
         self.assertEqual(200, resp['headers']['status'])
 
         # Include claimed messages this time, and echo
@@ -264,7 +264,7 @@ class ClaimsBaseTest(base.V1_1Base):
 
         req = test_utils.create_request(action, body, self.headers)
         self.protocol.onMessage(req, False)
-        resp = json.loads(send_mock.call_args[0][0])
+        resp = jsonutils.loads(send_mock.call_args[0][0])
         self.assertEqual(200, resp['headers']['status'])
         self.assertEqual(len(claimed_messages), len(resp['body']['messages']))
 
@@ -278,8 +278,8 @@ class ClaimsBaseTest(base.V1_1Base):
 
         req = test_utils.create_request(action, body, self.headers)
         self.protocol.onMessage(req, False)
-        resp = json.loads(send_mock.call_args[0][0])
-        self.assertEqual(403,  resp['headers']['status'])
+        resp = jsonutils.loads(send_mock.call_args[0][0])
+        self.assertEqual(403, resp['headers']['status'])
 
         # Delete the message and its associated claim
         body = {"queue_name": "skittle",
@@ -288,12 +288,12 @@ class ClaimsBaseTest(base.V1_1Base):
 
         req = test_utils.create_request(action, body, self.headers)
         self.protocol.onMessage(req, False)
-        resp = json.loads(send_mock.call_args[0][0])
+        resp = jsonutils.loads(send_mock.call_args[0][0])
         self.assertEqual(204, resp['headers']['status'])
 
         # Try to get it from the wrong project
         headers = {
-            'Client-ID': str(uuid.uuid4()),
+            'Client-ID': uuidutils.generate_uuid(),
             'X-Project-ID': 'someproject'
         }
 
@@ -302,8 +302,8 @@ class ClaimsBaseTest(base.V1_1Base):
                 "message_id": message_id_2}
         req = test_utils.create_request(action, body, headers)
         self.protocol.onMessage(req, False)
-        resp = json.loads(send_mock.call_args[0][0])
-        self.assertEqual(404,  resp['headers']['status'])
+        resp = jsonutils.loads(send_mock.call_args[0][0])
+        self.assertEqual(404, resp['headers']['status'])
 
         # Get the message
         action = consts.MESSAGE_GET
@@ -311,7 +311,7 @@ class ClaimsBaseTest(base.V1_1Base):
                 "message_id": message_id_2}
         req = test_utils.create_request(action, body, self.headers)
         self.protocol.onMessage(req, False)
-        resp = json.loads(send_mock.call_args[0][0])
+        resp = jsonutils.loads(send_mock.call_args[0][0])
         self.assertEqual(200, resp['headers']['status'])
 
         # Update the claim
@@ -323,7 +323,7 @@ class ClaimsBaseTest(base.V1_1Base):
                 "claim_id": claim_id}
         req = test_utils.create_request(action, body, self.headers)
         self.protocol.onMessage(req, False)
-        resp = json.loads(send_mock.call_args[0][0])
+        resp = jsonutils.loads(send_mock.call_args[0][0])
         self.assertEqual(204, resp['headers']['status'])
 
         # Get the claimed messages (again)
@@ -333,14 +333,18 @@ class ClaimsBaseTest(base.V1_1Base):
         req = test_utils.create_request(action, body, self.headers)
         self.protocol.onMessage(req, False)
         query = timeutils.utcnow()
-        resp = json.loads(send_mock.call_args[0][0])
+        resp = jsonutils.loads(send_mock.call_args[0][0])
         self.assertEqual(200, resp['headers']['status'])
         self.assertEqual(60, resp['body']['ttl'])
 
         message_id_3 = resp['body']['messages'][0]['id']
 
         estimated_age = timeutils.delta_seconds(creation, query)
-        self.assertTrue(estimated_age > resp['body']['age'])
+        # The claim's age should be 0 at this moment. But in some unexpected
+        # case, such as slow test, the age maybe larger than 0. Just skip
+        # asserting if so.
+        if resp['body']['age'] == 0:
+            self.assertGreater(estimated_age, resp['body']['age'])
 
         # Delete the claim
         action = consts.CLAIM_DELETE
@@ -348,7 +352,7 @@ class ClaimsBaseTest(base.V1_1Base):
                 "claim_id": claim_id}
         req = test_utils.create_request(action, body, self.headers)
         self.protocol.onMessage(req, False)
-        resp = json.loads(send_mock.call_args[0][0])
+        resp = jsonutils.loads(send_mock.call_args[0][0])
         self.assertEqual(204, resp['headers']['status'])
 
         # Try to delete a message with an invalid claim ID
@@ -359,7 +363,7 @@ class ClaimsBaseTest(base.V1_1Base):
 
         req = test_utils.create_request(action, body, self.headers)
         self.protocol.onMessage(req, False)
-        resp = json.loads(send_mock.call_args[0][0])
+        resp = jsonutils.loads(send_mock.call_args[0][0])
         self.assertEqual(400, resp['headers']['status'])
 
         # Make sure it wasn't deleted!
@@ -368,7 +372,7 @@ class ClaimsBaseTest(base.V1_1Base):
                 "message_id": message_id_2}
         req = test_utils.create_request(action, body, self.headers)
         self.protocol.onMessage(req, False)
-        resp = json.loads(send_mock.call_args[0][0])
+        resp = jsonutils.loads(send_mock.call_args[0][0])
         self.assertEqual(200, resp['headers']['status'])
 
         # Try to get a claim that doesn't exist
@@ -377,8 +381,8 @@ class ClaimsBaseTest(base.V1_1Base):
                 "claim_id": claim_id}
         req = test_utils.create_request(action, body, self.headers)
         self.protocol.onMessage(req, False)
-        resp = json.loads(send_mock.call_args[0][0])
-        self.assertEqual(404,  resp['headers']['status'])
+        resp = jsonutils.loads(send_mock.call_args[0][0])
+        self.assertEqual(404, resp['headers']['status'])
 
         # Try to update a claim that doesn't exist
         action = consts.CLAIM_UPDATE
@@ -388,8 +392,8 @@ class ClaimsBaseTest(base.V1_1Base):
                 "claim_id": claim_id}
         req = test_utils.create_request(action, body, self.headers)
         self.protocol.onMessage(req, False)
-        resp = json.loads(send_mock.call_args[0][0])
-        self.assertEqual(404,  resp['headers']['status'])
+        resp = jsonutils.loads(send_mock.call_args[0][0])
+        self.assertEqual(404, resp['headers']['status'])
 
     def test_post_claim_nonexistent_queue(self):
         action = consts.CLAIM_CREATE
@@ -402,7 +406,7 @@ class ClaimsBaseTest(base.V1_1Base):
 
         req = test_utils.create_request(action, body, self.headers)
         self.protocol.onMessage(req, False)
-        resp = json.loads(send_mock.call_args[0][0])
+        resp = jsonutils.loads(send_mock.call_args[0][0])
         self.assertEqual(204, resp['headers']['status'])
 
     def test_get_claim_nonexistent_queue(self):
@@ -415,8 +419,8 @@ class ClaimsBaseTest(base.V1_1Base):
 
         req = test_utils.create_request(action, body, self.headers)
         self.protocol.onMessage(req, False)
-        resp = json.loads(send_mock.call_args[0][0])
-        self.assertEqual(404,  resp['headers']['status'])
+        resp = jsonutils.loads(send_mock.call_args[0][0])
+        self.assertEqual(404, resp['headers']['status'])
 
     def _get_a_claim(self):
         action = consts.CLAIM_CREATE
@@ -429,7 +433,7 @@ class ClaimsBaseTest(base.V1_1Base):
 
         req = test_utils.create_request(action, body, self.headers)
         self.protocol.onMessage(req, False)
-        resp = json.loads(send_mock.call_args[0][0])
+        resp = jsonutils.loads(send_mock.call_args[0][0])
         self.assertEqual(201, resp['headers']['status'])
 
         return resp
