@@ -26,16 +26,38 @@ no common way to specify / pass configuration files
 to the WSGI app when it is called from other apps.
 """
 
+import threading
+
 from oslo_config import cfg
+from oslo_log import log
+from oslo_reports import guru_meditation_report as gmr
+from oslo_reports import opts as gmr_opts
 
 from zaqar import bootstrap
+from zaqar import version
 
-# TODO(kgriffs): For now, we have to use the global config
-# to pick up common options from openstack.common.log, since
-# that module uses the global CONF instance exclusively.
-conf = cfg.CONF
-conf(project='zaqar', prog='zaqar-queues', args=[])
+# Use the global CONF instance
+CONF = cfg.CONF
 
-boot = bootstrap.Bootstrap(conf)
-conf.drivers.transport = 'wsgi'
-app = boot.transport.app
+
+def init_application():
+    gmr_opts.set_defaults(CONF)
+    log.register_options(CONF)
+    CONF(project='zaqar', prog='zaqar-queues', args=[])
+    log.setup(CONF, 'zaqar')
+
+    gmr.TextGuruMeditation.setup_autorun(version, conf=CONF)
+
+    boot = bootstrap.Bootstrap(CONF)
+    CONF.drivers.transport = 'wsgi'
+    return boot.transport.app
+
+
+app = application = None
+
+lock = threading.Lock()
+with lock:
+    if application is None:
+        application = init_application()
+        # Keep the old name for compatibility
+        app = application
