@@ -15,7 +15,9 @@
 
 from oslo_log import log as logging
 
+from zaqar.common import decorators
 from zaqar.i18n import _
+from zaqar.transport import acl
 from zaqar.transport import utils
 from zaqar.transport.wsgi import errors as wsgi_errors
 
@@ -29,11 +31,13 @@ class Resource(object):
     def __init__(self, driver):
         self._driver = driver
 
+    @decorators.TransportLog("Health item")
+    @acl.enforce("health:get")
     def on_get(self, req, resp, **kwargs):
         try:
             resp_dict = self._driver.health()
-            resp.body = utils.to_json(resp_dict)
-        except Exception as ex:
-            LOG.exception(ex)
-            description = _(u'Health status could not be read.')
+            resp.text = utils.to_json(resp_dict)
+        except Exception:
+            description = _('Health status could not be read.')
+            LOG.exception(description)
             raise wsgi_errors.HTTPServiceUnavailable(description)
