@@ -20,6 +20,7 @@ from zaqar.common import decorators
 from zaqar.common.transport.wsgi import helpers as wsgi_helpers
 from zaqar.i18n import _
 from zaqar.storage import errors as storage_errors
+from zaqar.transport import acl
 from zaqar.transport import utils
 from zaqar.transport import validation
 from zaqar.transport.wsgi import errors as wsgi_errors
@@ -35,22 +36,20 @@ class CollectionResource(object):
         '_queue_controller',
         '_wsgi_conf',
         '_validate',
-        '_message_post_spec',
+        '_default_message_ttl',
+        '_encryptor'
     )
 
     def __init__(self, wsgi_conf, validate,
                  message_controller, queue_controller,
-                 default_message_ttl):
+                 default_message_ttl, encryptor_factory):
 
         self._wsgi_conf = wsgi_conf
         self._validate = validate
         self._message_controller = message_controller
         self._queue_controller = queue_controller
-
-        self._message_post_spec = (
-            ('ttl', int, default_message_ttl),
-            ('body', '*', None),
-        )
+        self._default_message_ttl = default_message_ttl
+        self._encryptor = encryptor_factory.getEncryptor()
 
     # ----------------------------------------------------------------------
     # Helpers
@@ -65,12 +64,16 @@ class CollectionResource(object):
                 message_ids=ids,
                 project=project_id)
 
+            queue_meta = self._queue_controller.get_metadata(queue_name,
+                                                             project_id)
         except validation.ValidationFailed as ex:
             LOG.debug(ex)
             raise wsgi_errors.HTTPBadRequestAPI(str(ex))
-
+        except storage_errors.QueueDoesNotExist:
+            LOG.exception('Queue name "%s" does not exist', queue_name)
+            queue_meta = None
         except Exception:
-            description = _(u'Message could not be retrieved.')
+            description = _('Message could not be retrieved.')
             LOG.exception(description)
             raise wsgi_errors.HTTPServiceUnavailable(description)
 
@@ -79,6 +82,10 @@ class CollectionResource(object):
         if not messages:
             return None
 
+        # Decrypt messages
+        if queue_meta and queue_meta.get('_enable_encrypt_messages', False):
+            self._encryptor.message_decrypted(messages)
+
         messages = [wsgi_utils.format_message_v1_1(m, base_path, m['claim_id'])
                     for m in messages]
 
@@ -94,8 +101,26 @@ class CollectionResource(object):
         req.get_param_as_int('limit', store=kwargs)
         req.get_param_as_bool('echo', store=kwargs)
         req.get_param_as_bool('include_claimed', store=kwargs)
+        req.get_param_as_bool('include_delayed', store=kwargs)
 
         try:
+            queue_meta = {}
+            try:
+                # NOTE(cdyangzhenyu): In order to determine whether the
+                # queue has a delay attribute, the metadata of the queue
+                # is obtained here. This may have a little performance impact.
+                # So maybe a refactor is needed in the future.
+                queue_meta = self._queue_controller.get_metadata(queue_name,
+                                                                 project_id)
+            except storage_errors.DoesNotExist:
+                LOG.exception('Queue name "%s" does not exist', queue_name)
+            queue_delay = queue_meta.get('_default_message_delay')
+            if not queue_delay:
+                # NOTE(cdyangzhenyu): If the queue without the metadata
+                # attribute _default_message_delay, we don't filter
+                # for delay messages.
+                kwargs['include_delayed'] = True
+
             self._validate.message_listing(**kwargs)
             results = self._message_controller.list(
                 queue_name,
@@ -107,6 +132,10 @@ class CollectionResource(object):
             cursor = next(results)
             messages = list(cursor)
 
+            # Decrypt messages
+            if queue_meta.get('_enable_encrypt_messages', False):
+                self._encryptor.message_decrypted(messages)
+
         except validation.ValidationFailed as ex:
             LOG.debug(ex)
             raise wsgi_errors.HTTPBadRequestAPI(str(ex))
@@ -116,7 +145,7 @@ class CollectionResource(object):
             messages = None
 
         except Exception:
-            description = _(u'Messages could not be listed.')
+            description = _('Messages could not be listed.')
             LOG.exception(description)
             raise wsgi_errors.HTTPServiceUnavailable(description)
 
@@ -150,12 +179,40 @@ class CollectionResource(object):
     # ----------------------------------------------------------------------
 
     @decorators.TransportLog("Messages collection")
+    @acl.enforce("messages:create")
     def on_post(self, req, resp, project_id, queue_name):
         client_uuid = wsgi_helpers.get_client_uuid(req)
-
         try:
+            # NOTE(flwang): Replace 'exists' with 'get_metadata' won't impact
+            # the performance since both of them will call
+            # collection.find_one()
+            queue_meta = None
+            try:
+                queue_meta = self._queue_controller.get_metadata(queue_name,
+                                                                 project_id)
+            except storage_errors.DoesNotExist:
+                self._validate.queue_identification(queue_name, project_id)
+                self._queue_controller.create(queue_name, project=project_id)
+                # NOTE(flwang): Queue is created in lazy mode, so no metadata
+                # set.
+                queue_meta = {}
+
+            queue_max_msg_size = queue_meta.get('_max_messages_post_size')
+            queue_default_ttl = queue_meta.get('_default_message_ttl')
+            queue_delay = queue_meta.get('_default_message_delay')
+            queue_encrypted = queue_meta.get('_enable_encrypt_messages', False)
+
+            if queue_default_ttl:
+                message_post_spec = (('ttl', int, queue_default_ttl),
+                                     ('body', '*', None),)
+            else:
+                message_post_spec = (('ttl', int, self._default_message_ttl),
+                                     ('body', '*', None),)
+            if queue_delay:
+                message_post_spec += (('delay', int, queue_delay),)
             # Place JSON size restriction before parsing
-            self._validate.message_length(req.content_length)
+            self._validate.message_length(req.content_length,
+                                          max_msg_post_size=queue_max_msg_size)
         except validation.ValidationFailed as ex:
             LOG.debug(ex)
             raise wsgi_errors.HTTPBadRequestAPI(str(ex))
@@ -164,18 +221,18 @@ class CollectionResource(object):
         document = wsgi_utils.deserialize(req.stream, req.content_length)
 
         if 'messages' not in document:
-            description = _(u'No messages were found in the request body.')
+            description = _('No messages were found in the request body.')
             raise wsgi_errors.HTTPBadRequestAPI(description)
 
         messages = wsgi_utils.sanitize(document['messages'],
-                                       self._message_post_spec,
+                                       message_post_spec,
                                        doctype=wsgi_utils.JSONArray)
 
         try:
             self._validate.message_posting(messages)
 
-            if not self._queue_controller.exists(queue_name, project_id):
-                self._queue_controller.create(queue_name, project=project_id)
+            if queue_encrypted:
+                self._encryptor.message_encrypted(messages)
 
             message_ids = self._message_controller.post(
                 queue_name,
@@ -192,12 +249,12 @@ class CollectionResource(object):
             raise wsgi_errors.HTTPNotFound(str(ex))
 
         except storage_errors.MessageConflict:
-            description = _(u'No messages could be enqueued.')
+            description = _('No messages could be enqueued.')
             LOG.exception(description)
             raise wsgi_errors.HTTPServiceUnavailable(description)
 
         except Exception:
-            description = _(u'Messages could not be enqueued.')
+            description = _('Messages could not be enqueued.')
             LOG.exception(description)
             raise wsgi_errors.HTTPServiceUnavailable(description)
 
@@ -207,10 +264,11 @@ class CollectionResource(object):
 
         hrefs = [req.path + '/' + id for id in message_ids]
         body = {'resources': hrefs}
-        resp.body = utils.to_json(body)
+        resp.text = utils.to_json(body)
         resp.status = falcon.HTTP_201
 
     @decorators.TransportLog("Messages collection")
+    @acl.enforce("messages:get_all")
     def on_get(self, req, resp, project_id, queue_name):
         ids = req.get_param_as_list('ids')
 
@@ -225,22 +283,26 @@ class CollectionResource(object):
             # NOTE(TheSriram): Trying to get a message by id, should
             # return the message if its present, otherwise a 404 since
             # the message might have been deleted.
-            msg = _(u'No messages with IDs: {ids} found in the queue {queue} '
-                    u'for project {project}.')
+            msg = _('No messages with IDs: {ids} found in the queue {queue} '
+                    'for project {project}.')
             description = msg.format(queue=queue_name, project=project_id,
                                      ids=ids)
             raise wsgi_errors.HTTPNotFound(description)
 
         else:
-            resp.body = utils.to_json(response)
+            resp.text = utils.to_json(response)
         # status defaults to 200
 
     @decorators.TransportLog("Messages collection")
+    @acl.enforce("messages:delete_all")
     def on_delete(self, req, resp, project_id, queue_name):
         ids = req.get_param_as_list('ids')
+        claim_ids = None
+        if self._validate.get_limit_conf_value('message_delete_with_claim_id'):
+            claim_ids = req.get_param_as_list('claim_ids')
         pop_limit = req.get_param_as_int('pop')
         try:
-            self._validate.message_deletion(ids, pop_limit)
+            self._validate.message_deletion(ids, pop_limit, claim_ids)
 
         except validation.ValidationFailed as ex:
             LOG.debug(ex)
@@ -248,22 +310,24 @@ class CollectionResource(object):
 
         if ids:
             resp.status = self._delete_messages_by_id(queue_name, ids,
-                                                      project_id)
+                                                      project_id, claim_ids)
 
         elif pop_limit:
-            resp.status, resp.body = self._pop_messages(queue_name,
+            resp.status, resp.text = self._pop_messages(queue_name,
                                                         project_id,
                                                         pop_limit)
 
-    def _delete_messages_by_id(self, queue_name, ids, project_id):
+    def _delete_messages_by_id(self, queue_name, ids, project_id,
+                               claim_ids=None):
         try:
             self._message_controller.bulk_delete(
                 queue_name,
                 message_ids=ids,
-                project=project_id)
+                project=project_id,
+                claim_ids=claim_ids)
 
         except Exception:
-            description = _(u'Messages could not be deleted.')
+            description = _('Messages could not be deleted.')
             LOG.exception(description)
             raise wsgi_errors.HTTPServiceUnavailable(description)
 
@@ -271,8 +335,8 @@ class CollectionResource(object):
 
     def _pop_messages(self, queue_name, project_id, pop_limit):
         try:
-            LOG.debug(u'POP messages - queue: %(queue)s, '
-                      u'project: %(project)s',
+            LOG.debug('POP messages - queue: %(queue)s, '
+                      'project: %(project)s',
                       {'queue': queue_name, 'project': project_id})
 
             messages = self._message_controller.pop(
@@ -281,7 +345,7 @@ class CollectionResource(object):
                 limit=pop_limit)
 
         except Exception:
-            description = _(u'Messages could not be popped.')
+            description = _('Messages could not be popped.')
             LOG.exception(description)
             raise wsgi_errors.HTTPServiceUnavailable(description)
 
@@ -296,12 +360,20 @@ class CollectionResource(object):
 
 class ItemResource(object):
 
-    __slots__ = '_message_controller'
+    __slots__ = (
+        '_message_controller',
+        '_queue_controller',
+        '_encryptor'
+    )
 
-    def __init__(self, message_controller):
+    def __init__(self, message_controller, queue_controller,
+                 encryptor_factory):
         self._message_controller = message_controller
+        self._queue_controller = queue_controller
+        self._encryptor = encryptor_factory.getEncryptor()
 
     @decorators.TransportLog("Messages item")
+    @acl.enforce("messages:get")
     def on_get(self, req, resp, project_id, queue_name, message_id):
         try:
             message = self._message_controller.get(
@@ -309,12 +381,18 @@ class ItemResource(object):
                 message_id,
                 project=project_id)
 
+            queue_meta = self._queue_controller.get_metadata(queue_name,
+                                                             project_id)
+            # Decrypt messages
+            if queue_meta.get('_enable_encrypt_messages', False):
+                self._encryptor.message_decrypted([message])
+
         except storage_errors.DoesNotExist as ex:
             LOG.debug(ex)
             raise wsgi_errors.HTTPNotFound(str(ex))
 
         except Exception:
-            description = _(u'Message could not be retrieved.')
+            description = _('Message could not be retrieved.')
             LOG.exception(description)
             raise wsgi_errors.HTTPServiceUnavailable(description)
 
@@ -324,12 +402,13 @@ class ItemResource(object):
                                                  req.path.rsplit('/', 2)[0],
                                                  message['claim_id'])
 
-        resp.body = utils.to_json(message)
+        resp.text = utils.to_json(message)
         # status defaults to 200
 
     @decorators.TransportLog("Messages item")
+    @acl.enforce("messages:delete")
     def on_delete(self, req, resp, project_id, queue_name, message_id):
-        error_title = _(u'Unable to delete')
+        error_title = _('Unable to delete')
 
         try:
             self._message_controller.delete(
@@ -340,24 +419,27 @@ class ItemResource(object):
 
         except storage_errors.MessageNotClaimed as ex:
             LOG.debug(ex)
-            description = _(u'A claim was specified, but the message '
-                            u'is not currently claimed.')
-            raise falcon.HTTPBadRequest(error_title, description)
+            description = _('A claim was specified, but the message '
+                            'is not currently claimed.')
+            raise falcon.HTTPBadRequest(
+                title=error_title, description=description)
 
         except storage_errors.ClaimDoesNotExist as ex:
             LOG.debug(ex)
-            description = _(u'The specified claim does not exist or '
-                            u'has expired.')
-            raise falcon.HTTPBadRequest(error_title, description)
+            description = _('The specified claim does not exist or '
+                            'has expired.')
+            raise falcon.HTTPBadRequest(
+                title=error_title, description=description)
 
         except storage_errors.NotPermitted as ex:
             LOG.debug(ex)
-            description = _(u'This message is claimed; it cannot be '
-                            u'deleted without a valid claim ID.')
-            raise falcon.HTTPForbidden(error_title, description)
+            description = _('This message is claimed; it cannot be '
+                            'deleted without a valid claim ID.')
+            raise falcon.HTTPForbidden(
+                title=error_title, description=description)
 
         except Exception:
-            description = _(u'Message could not be deleted.')
+            description = _('Message could not be deleted.')
             LOG.exception(description)
             raise wsgi_errors.HTTPServiceUnavailable(description)
 
