@@ -15,16 +15,14 @@
 import os
 
 from oslo_log import log as logging
-import six
 
+from zaqar.common import decorators
 from zaqar.common import urls
-from zaqar import i18n
+from zaqar.transport import acl
 from zaqar.transport import utils
 from zaqar.transport.wsgi import errors as wsgi_errors
 from zaqar.transport.wsgi import utils as wsgi_utils
 
-_ = i18n._
-_LE = i18n._LE
 LOG = logging.getLogger(__name__)
 
 _KNOWN_KEYS = {'methods', 'expires', 'paths'}
@@ -40,20 +38,22 @@ class Resource(object):
         self._driver = driver
         self._conf = driver._conf
 
+    @decorators.TransportLog("Queues share item")
+    @acl.enforce("queues:share")
     def on_post(self, req, resp, project_id, queue_name):
-        LOG.debug(u'Pre-Signed URL Creation for queue: %(queue)s, '
-                  u'project: %(project)s',
+        LOG.debug('Pre-Signed URL Creation for queue: %(queue)s, '
+                  'project: %(project)s',
                   {'queue': queue_name, 'project': project_id})
 
         try:
             document = wsgi_utils.deserialize(req.stream, req.content_length)
         except ValueError as ex:
             LOG.debug(ex)
-            raise wsgi_errors.HTTPBadRequestAPI(six.text_type(ex))
+            raise wsgi_errors.HTTPBadRequestAPI(str(ex))
 
         diff = set(document.keys()) - _KNOWN_KEYS
         if diff:
-            msg = six.text_type(_LE('Unknown keys: %s') % diff)
+            msg = str('Unknown keys: %s' % diff)
             raise wsgi_errors.HTTPBadRequestAPI(msg)
 
         key = self._conf.signed_url.secret_key
@@ -63,7 +63,7 @@ class Resource(object):
         else:
             diff = set(paths) - _VALID_PATHS
             if diff:
-                msg = six.text_type(_LE('Invalid paths: %s') % diff)
+                msg = str('Invalid paths: %s' % diff)
                 raise wsgi_errors.HTTPBadRequestAPI(msg)
             paths = [os.path.join(req.path[:-6], path) for path in paths]
 
@@ -74,4 +74,4 @@ class Resource(object):
         except ValueError as err:
             raise wsgi_errors.HTTPBadRequestAPI(str(err))
 
-        resp.body = utils.to_json(data)
+        resp.text = utils.to_json(data)
